Struct cursive_core::buffer::Window

source ·
pub struct Window<'a> { /* private fields */ }
A view into a rectangular area of the buffer.

Implementations

source

impl<'a> Window<'a>

source

pub fn cell_at(&self, pos: Vec2) -> Option<&Cell>

Returns the cell at the given location.

Returns None if the cell is empty because the previous one was double-wide.

source

pub fn rows(&self) -> impl Iterator<Item = &[Option<Cell>]>

Iterate on the rows of this window.

source

pub fn viewport(&self) -> Rect

Returns the viewport this window is covering.

source

pub fn size(&self) -> Vec2

Returns the size of this window.

source

pub fn style_at_mut<V>(&mut self, pos: V) -> Option<&mut ConcreteStyle>
where V: Into<Vec2>,

Get mutable access to the style at the given cell, if any.