Struct cursive_core::builder::Context

source ·
pub struct Context { /* private fields */ }
Everything needed to prepare a view from a config.

  • Current blueprints
  • Any stored variables/callbacks

Cheap to clone (uses Arc internally).

Implementations

source

impl Context

source

pub fn new() -> Self

Prepare a new context using registered blueprints.

source

pub fn resolve_as_var<T: 'static + Resolvable>( &self, config: &Config, ) -> Result<T, Error>

Resolve a value.

Needs to be a reference to a variable.

source

pub fn resolve_as_config<T: Resolvable + 'static>( &self, config: &Config, ) -> Result<T, Error>

Resolve a value straight from the config.

This will not attempt to load the value as a variable if the config is a string.

Note however that while loading as a config, it may still resolve nested values as variables.

source

pub fn resolve<T: Resolvable + 'static>( &self, config: &Config, ) -> Result<T, Error>

Resolve a value

source

pub fn resolve_or<T: Resolvable + 'static>( &self, config: &Config, if_missing: T, ) -> Result<T, Error>

Resolve a value, using the given default if the key is missing.

source

pub fn store_once<T>(&mut self, name: impl Into<String>, value: T)
where T: Send + 'static,

Store a new variable that can only be resolved once.

source

pub fn store_with<T: 'static>( &mut self, name: impl Into<String>, maker: impl 'static + Fn(&Config, &Context) -> Result<T, Error> + Send + Sync, )

Store a new variable maker.

source

pub fn store<S, T>(&mut self, name: S, value: T)
where S: Into<String>, T: Clone + Send + Sync + 'static,

Store a new variable for resolution.

Can be a callback, a usize, …

source

pub fn store_view<S, T>(&mut self, name: S, view: T)
where S: Into<String>, T: IntoBoxedView,

Store a view for resolution.

The view can be resolved as a BoxedView.

Note that this will only resolve this view once.

If the view should be resolved more than that, consider calling store_with and re-constructing a BoxedView (maybe by cloning your view) every time.

source

pub fn store_config( &mut self, name: impl Into<String>, config: impl Into<Config>, )

Store a new config.

source

pub fn store_proxy( &mut self, name: impl Into<String>, new_name: impl Into<String>, )

Store a new variable proxy.

source

pub fn register_blueprint<F>(&mut self, name: impl Into<String>, blueprint: F)
where F: Fn(&Config, &Context) -> Result<BoxedView, Error> + 'static + Send + Sync,

Register a new blueprint for this context only.

source

pub fn register_wrapper_blueprint<F>( &mut self, name: impl Into<String>, blueprint: F, )
where F: Fn(&Config, &Context) -> Result<Wrapper, Error> + 'static + Send + Sync,

Register a new wrapper blueprint for this context only.

source

pub fn load<T: Resolvable + Any>( &self, name: &str, config: &Config, ) -> Result<T, Error>

Loads a variable of the given type.

If a variable with this name is found but is a Config, tries to deserialize it.

Note: config can be &Config::Null for loading simple variables.

source

pub fn build_wrapper(&self, config: &Config) -> Result<Wrapper, Error>

Build a wrapper with the given config

source

pub fn validate(&self, config: &Config) -> Result<(), ConfigError>

Validate a config.

Returns an error if any variable is missing or used more than once.

source

pub fn build(&self, config: &Config) -> Result<BoxedView, Error>

Build a new view from the given config.

source

pub fn sub_context<F>(&self, f: F) -> Context
where F: FnOnce(&mut Context),

Prepare a new context with some variable overrides.

source

pub fn build_template( &self, config: &Config, template: &Config, ) -> Result<BoxedView, Error>

Builds a view from a template config.

template should be a config describing a view, potentially using variables. Any value in config will be stored as a variable when rendering the template.