Trait cursive_core::builder::Resolvable

source ·
pub trait Resolvable {
    // Provided methods
    fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>
       where Self: Sized { ... }
    fn from_any(any: Box<dyn Any>) -> Option<Self>
       where Self: Sized + Any { ... }
}
Trait for types that can be resolved from a context.

They can be loaded from a config (yaml), or from a stored value (Box<Any>).

Provided Methods

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>
where Self: Sized,

Build from a config (a JSON value).

The default implementation always fails.

source

fn from_any(any: Box<dyn Any>) -> Option<Self>
where Self: Sized + Any,

Build from an Any variable.

Default implementation tries to downcast to Self.

Override if you want to try downcasting to other types as well.

Implementations on Foreign Types

source

impl Resolvable for bool

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for f32

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for f64

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for i8

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for i16

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for i32

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for i64

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for i128

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for isize

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for u8

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for u16

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for u32

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for u64

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for u128

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for usize

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

impl Resolvable for Box<dyn View>

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

impl Resolvable for String

source

fn from_config(config: &Config, _context: &Context) -> Result<Self, Error>

source

fn from_any(any: Box<dyn Any>) -> Option<Self>
where Self: Sized + Any,

source

impl<A, B> Resolvable for (A, B)
where A: Resolvable + 'static, B: Resolvable + 'static,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>
where Self: Sized,

source

impl<A, B, C> Resolvable for (A, B, C)
where A: Resolvable + 'static, B: Resolvable + 'static, C: Resolvable + 'static,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>
where Self: Sized,

source

impl<Res, A> Resolvable for Arc<dyn Fn(A) -> Res + Send + Sync>

source

impl<Res, A, B> Resolvable for Arc<dyn Fn(A, B) -> Res + Send + Sync>

source

impl<Res, A, B, C> Resolvable for Arc<dyn Fn(A, B, C) -> Res + Send + Sync>

source

impl<Res, A, B, C, D> Resolvable for Arc<dyn Fn(A, B, C, D) -> Res + Send + Sync>

source

impl<Res, A, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, C, &D) -> Res + Send + Sync>

source

impl<Res, A, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized> Resolvable for Arc<dyn Fn(A, B, &C) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized> Resolvable for Arc<dyn Fn(A, B, &mut C) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, B, &C, D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized> Resolvable for Arc<dyn Fn(A, &B) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C> Resolvable for Arc<dyn Fn(A, &B, C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C> Resolvable for Arc<dyn Fn(A, &mut B, C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(A, &B, C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(A, &mut B, C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &mut C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &mut C) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, &B, &C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, &B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, &mut B, &C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(A, &mut B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(A, &mut B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized> Resolvable for Arc<dyn Fn(&A) -> Res + Send + Sync>

source

impl<Res, A: ?Sized> Resolvable for Arc<dyn Fn(&mut A) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B> Resolvable for Arc<dyn Fn(&A, B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B> Resolvable for Arc<dyn Fn(&mut A, B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C> Resolvable for Arc<dyn Fn(&A, B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C> Resolvable for Arc<dyn Fn(&mut A, B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D> Resolvable for Arc<dyn Fn(&A, B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D> Resolvable for Arc<dyn Fn(&mut A, B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized> Resolvable for Arc<dyn Fn(&A, &B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C> Resolvable for Arc<dyn Fn(&A, &B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C> Resolvable for Arc<dyn Fn(&A, &mut B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C> Resolvable for Arc<dyn Fn(&mut A, &B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C> Resolvable for Arc<dyn Fn(&mut A, &mut B, C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(&A, &B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(&A, &mut B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(&mut A, &B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D> Resolvable for Arc<dyn Fn(&mut A, &mut B, C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &mut C) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, &B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, &B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, &mut B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&A, &mut B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, &B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, &B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, &mut B, &C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D> Resolvable for Arc<dyn Fn(&mut A, &mut B, &mut C, D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&A, &mut B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &C, &mut D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &mut C, &D) -> Res + Send + Sync>

source

impl<Res, A: ?Sized, B: ?Sized, C: ?Sized, D: ?Sized> Resolvable for Arc<dyn Fn(&mut A, &mut B, &mut C, &mut D) -> Res + Send + Sync>

source

impl<T> Resolvable for Option<T>
where T: Resolvable,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

fn from_any(any: Box<dyn Any>) -> Option<Self>
where Self: Sized + Any,

source

impl<T> Resolvable for Box<T>
where T: 'static + Resolvable,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

impl<T> Resolvable for Arc<T>
where T: 'static + Resolvable,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

fn from_any(any: Box<dyn Any>) -> Option<Self>

source

impl<T> Resolvable for Vec<T>
where T: 'static + Resolvable,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

impl<T> Resolvable for HashMap<String, T>
where T: 'static + Resolvable,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

source

impl<T, const N: usize> Resolvable for [T; N]
where T: 'static + Resolvable + Clone,

source

fn from_any(any: Box<dyn Any>) -> Option<Self>
where Self: Sized + Any,

source

fn from_config(config: &Config, context: &Context) -> Result<Self, Error>

Implementors