Enum cursive_core::direction::Relative

source ·
pub enum Relative {
    Front,
    Back,
}
Direction relative to an orientation.

Variants



Front

Front relative direction.

  • Horizontally, this means Left
  • Vertically, this means Up


Back

Back relative direction.

  • Horizontally, this means Right
  • Vertically, this means Down.

Implementations

source

impl Relative

source

pub const fn absolute(self, orientation: Orientation) -> Absolute

Returns the absolute direction in the given orientation.

source

pub fn pick<T>(self, (front, back): (T, T)) -> T

Picks one of the two values in a tuple.

First one is self is Front, second one if self is Back.

source

pub const fn swap(self) -> Self

Returns the other relative direction.

source

pub const fn a_to_b(a: usize, b: usize) -> Option<Self>

Returns the position of a relative to b.

If a < b, it would be Front. If a > b, it would be Back. If a == b, returns None.