Module cursive_core::logger

source ·
Logging utilities.

Structs

Functions

  • Return a logger that stores records in cursive’s log queue.
  • Initialize the Cursive logger.
  • Log a record in cursive’s log queue.
  • Adds n more entries to cursive’s log queue.
  • Sets the external log filter level.
  • Sets log filter levels based on environment variables RUST_LOG and CURSIVE_LOG. If RUST_LOG is set, then both internal and external log levels are set to match. If CURSIVE_LOG is set, then the internal log level is set to match with precedence over RUST_LOG.
  • Sets the internal log filter level.