[−][src]Function cursive_core::logger::init
pub fn init()
Initialize the Cursive logger.
Make sure this is the only logger your are using.
Use a DebugView to see the logs, or use
Cursive::toggle_debug_console().
pub fn init()
Initialize the Cursive logger.
Make sure this is the only logger your are using.
Use a DebugView to see the logs, or use
Cursive::toggle_debug_console().