Struct cursive_core::utils::lines::simple::Row [−][src]
Represents a row of text within a String.
A row is made of offsets into a parent String.
The corresponding substring should take width cells when printed.
Fields
start: usizeBeginning of the row in the parent String.
end: usizeEnd of the row (excluded)
width: usizeWidth of the row, in cells.
is_wrapped: boolWhether or not this text was wrapped onto the next line
Implementations