SpannedStr

Struct SpannedStr 

pub struct SpannedStr<'a, T> { /* private fields */ }
The immutable, borrowed equivalent of SpannedString.

Implementations

Source

impl<'a, T> SpannedStr<'a, T>
where T: 'a,

pub const fn new(source: &'a str, spans: &'a [IndexedSpan<T>]) -> Self

Creates a new SpannedStr from the given references.

pub const fn empty() -> Self

Creates a new empty SpannedStr.

pub fn spans<'b>( &'b self, ) -> impl DoubleEndedIterator<Item = Span<'a, T>> + ExactSizeIterator<Item = Span<'a, T>> + 'b
where 'a: 'b,

Gives access to the parsed styled spans.

pub const fn spans_raw(&self) -> &'a [IndexedSpan<T>]

Returns a reference to the indexed spans.

pub const fn source(&self) -> &'a str

Returns a reference to the source (non-parsed) string.

pub const fn is_empty(&self) -> bool

Returns true if self is empty.

Can be caused by an empty source, or no span.

pub fn width(&self) -> usize

Returns the width taken by this string.

This is the sum of the width of each span.

pub fn from_spanned_text<'b, S>(text: &'b S) -> Self
where S: SpannedText<S = IndexedSpan<T>>, 'b: 'a,

Create a new SpannedStr by borrowing from a SpannedText.