Struct cursive_core::view::Margins

source ·
pub struct Margins {
    pub left: usize,
    pub right: usize,
    pub top: usize,
    pub bottom: usize,
}
Four values representing each direction.

Fields

left: usize

Left margin

right: usize

Right margin

top: usize

Top margin

bottom: usize

Bottom margin

Implementations

source

impl Margins

source

pub fn zeroes() -> Self

Creates a new Margins object with zero margins.

source

pub fn lrtb(left: usize, right: usize, top: usize, bottom: usize) -> Self

Creates a new Margins object from the Left, Right, Top, Bottom fields.

source

pub fn ltrb(left_top: Vec2, right_bottom: Vec2) -> Self

Creates a new Margins object from the Left, Top, Right, Bottom fields.

source

pub fn trbl(top: usize, right: usize, bottom: usize, left: usize) -> Self

Creates a new Margins object from the Top, Right, Bottom, Left fields.

source

pub fn lr(left: usize, right: usize) -> Self

Creates a new Margins object from the Left and Right fields.

Top and Bottom will be 0.

source

pub fn tb(top: usize, bottom: usize) -> Self

Creates a new Margins object from the Top and Bottom fields.

Left and Right will be 0.

source

pub fn horizontal(&self) -> usize

Returns left + right.

source

pub fn vertical(&self) -> usize

Returns top + bottom.

source

pub fn combined(&self) -> Vec2

Returns (left+right, top+bottom).

source

pub fn top_left(&self) -> Vec2

Returns (left, top).

source

pub fn bot_right(&self) -> Vec2

Returns (right, bottom).