[−][src]Struct cursive_core::views::FixedLayout
Arranges its children in a fixed layout.
Usually meant to use an external layout engine.
Examples
use cursive_core::{ views::{FixedLayout, TextView, Button}, Rect, }; let layout = FixedLayout::new() .child(Rect::from_size((0,0), (1,1)), TextView::new("/")) .child(Rect::from_size((14,0), (1,1)), TextView::new(r"\")) .child(Rect::from_size((0,2), (1,1)), TextView::new(r"\")) .child(Rect::from_size((14,2), (1,1)), TextView::new("/")) .child(Rect::from_size((3,1), (11,1)), Button::new("Clickme", |s| s.quit()));
Implementations
impl FixedLayout[src]
pub fn new() -> Self[src]
Returns a new, empty FixedLayout.
pub fn child<V: IntoBoxedView>(self, position: Rect, view: V) -> Self[src]
Adds a child. Chainable variant.
pub fn add_child<V: IntoBoxedView>(&mut self, position: Rect, view: V)[src]
Adds a child.
pub fn get_focus_index(&self) -> usize[src]
Returns index of focused inner view
pub fn set_focus_index(&mut self, index: usize) -> Result<(), ()>[src]
Attemps to set the focus on the given child.
Returns Err(()) if index >= self.len(), or if the view at the
given index does not accept focus.
pub fn len(&self) -> usize[src]
How many children are in this view.
pub fn is_empty(&self) -> bool[src]
Returns true if this view has no children.
pub fn get_child(&self, i: usize) -> Option<&dyn View>[src]
Returns a reference to a child.
pub fn get_child_mut(&mut self, i: usize) -> Option<&mut dyn View>[src]
Returns a mutable reference to a child.
pub fn set_child_position(&mut self, i: usize, position: Rect)[src]
Sets the position for the given child.
pub fn remove_child(&mut self, i: usize) -> Option<Box<dyn View>>[src]
Removes a child.
If i is within bounds, the removed child will be returned.
pub fn find_child_from_name(&mut self, name: &str) -> Option<usize>[src]
Looks for the child containing a view with the given name.
Returns Some(i) if self.get_child(i) has the given name, or
contains a view with the given name.
Returns None if the given name was not found.