Struct cursive_core::views::ListView

source ·
pub struct ListView { /* private fields */ }
Displays a list of elements.

Implementations

source

impl ListView

source

pub fn new() -> Self

Creates a new, empty ListView.

source

pub fn len(&self) -> usize

Returns the number of children, including delimiters.

source

pub fn is_empty(&self) -> bool

Returns true if this view contains no children.

Returns false if at least a delimiter or a view is present.

source

pub fn children(&self) -> &[ListChild]

Returns a reference to the children

source

pub fn get_row(&self, id: usize) -> &ListChild

Returns a reference to the child at the given position.

source

pub fn row_mut(&mut self, id: usize) -> &mut ListChild

Gives mutable access to the child at the given position.

Panics

Panics if id >= self.len().

source

pub fn set_children(&mut self, children: Vec<ListChild>)

Sets the children for this view.

source

pub fn add_child<V: IntoBoxedView + 'static>( &mut self, label: impl Into<String>, view: V, )

Adds a view to the end of the list.

source

pub fn clear(&mut self)

Removes all children from this view.

source

pub fn child<V: IntoBoxedView + 'static>(self, label: &str, view: V) -> Self

Adds a view to the end of the list.

Chainable variant.

source

pub fn add_delimiter(&mut self)

Adds a delimiter to the end of the list.

source

pub fn delimiter(self) -> Self

Adds a delimiter to the end of the list.

Chainable variant.

source

pub fn remove_child(&mut self, index: usize) -> ListChild

Removes a child from the view.

Panics

If index >= self.len().

source

pub fn set_on_select<F>(&mut self, cb: F)
where F: Fn(&mut Cursive, &String) + 'static + Send + Sync,

Sets a callback to be used when an item is selected.

source

pub fn on_select_cb<F: Fn(&mut Cursive, &String) + 'static + Send + Sync>( cb: F, ) -> Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>

Helper method to store a callback of the correct type for Self::set_on_select.

This is mostly useful when using this view in a template.

source

pub fn set_on_select_cb( &mut self, cb: Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>, )

Helper method to call Self::set_on_select with a variable from a config.

This is mostly useful when writing a cursive blueprint for this view.

source

pub fn on_select<F>(self, cb: F) -> Self
where F: Fn(&mut Cursive, &String) + 'static + Send + Sync,

Sets a callback to be used when an item is selected.

Chainable variant.

source

pub fn focus(&self) -> usize

Returns the index of the currently focused item.

Panics if the list is empty.