Struct cursive_core::views::NamedView

source ·
pub struct NamedView<V> { /* private fields */ }
Wrapper around a view to make it identifiable.

This lets other views refer to this one using a string identifier.

See Nameable for an easy way to wrap any view with it.

Implementations

source

impl<V> NamedView<V>

source

pub fn new<S: Into<String>>(name: S, view: V) -> Self

Wraps view in a new NamedView.

source

pub fn get_mut(&mut self) -> ViewRef<V>

Gets mutable access to the inner view.

This returns a ViewRef<V>, which implement DerefMut<Target = V>.

Panics

Panics if another reference for this view already exists.

source

pub fn name(&self) -> &str

Returns the name attached to this view.

source

pub fn set_name<S: Into<String>>(&mut self, name: S)

Changes the name attached to this view.