Struct cursive_core::views::OnLayoutView
source · pub struct OnLayoutView<V> { /* private fields */ }Expand description
View wrapper overriding the View::layout method.
Implementations
sourceimpl<V: 'static> OnLayoutView<V>
impl<V: 'static> OnLayoutView<V>
sourcepub fn new<F>(view: V, on_layout: F) -> Self
pub fn new<F>(view: V, on_layout: F) -> Self
Wraps a view in an OnLayoutView.
Will run the given closure for layout instead of the one from view.
use cursive_core::{
views::{OnLayoutView, TextView},
View,
};
let view = TextView::new("foo");
// Here we just run the innver view's layout.
OnLayoutView::new(view, |v, s| v.layout(s));sourcepub fn wrap(view: V) -> Selfwhere
V: View,
pub fn wrap(view: V) -> Selfwhere
V: View,
Wraps a view in an OnLayoutView.
This is a shortcut for Self::new(view, V::layout)
You can change it later with set_on_layout.
sourcepub fn set_on_layout<F>(&mut self, on_layout: F)
pub fn set_on_layout<F>(&mut self, on_layout: F)
Replaces the callback to run.
sourcepub fn on_layout_cb<F: Fn(&mut V, Vec2) + 'static + Send + Sync>(
on_layout: F,
) -> Arc<dyn Fn(&mut V, Vec2) + Send + Sync>
pub fn on_layout_cb<F: Fn(&mut V, Vec2) + 'static + Send + Sync>( on_layout: F, ) -> Arc<dyn Fn(&mut V, Vec2) + Send + Sync>
Helper method to store a callback of the correct type for Self::set_on_layout.
This is mostly useful when using this view in a template.
sourcepub fn set_on_layout_cb(
&mut self,
on_layout: Arc<dyn Fn(&mut V, Vec2) + Send + Sync>,
)
pub fn set_on_layout_cb( &mut self, on_layout: Arc<dyn Fn(&mut V, Vec2) + Send + Sync>, )
Helper method to call Self::set_on_layout with a variable from a config.
This is mostly useful when writing a cursive blueprint for this view.
sourcepub fn get_inner_mut(&mut self) -> &mut V
pub fn get_inner_mut(&mut self) -> &mut V
Gets mutable access to the inner view.