Struct cursive_core::views::RadioGroup [−][src]
pub struct RadioGroup<T> { /* fields omitted */ }Expand description
Group to coordinate multiple radio buttons.
A RadioGroup is used to create and manage RadioButtons.
A RadioGroup can be cloned; it will keep pointing to the same group.
Implementations
Adds a new button to the group.
The button will display label next to it, and will embed value.
Returns the id of the selected button.
Buttons are indexed in the order they are created, starting from 0.
Sets a callback to be used when the selection changes.
Adds a button, using the label itself as value.