Struct cursive_core::views::ScreensView [−][src]
pub struct ScreensView<V = BoxedView> { /* fields omitted */ }
A view that can switch between different screens.
Implementations
Creates a new ScreensView with a single screen.
Returns a reference to the currently active screen.
Returns None if there is no active screen.
Returns a mutable reference to the currently active screen.
Returns the id of the currently active screen.
Adds a new screen, and returns its ID.
Convenient method to create a new screen, and set it as active.
Sets the active screen. Panics if no such screen exist.
Draws the background.
This is mostly used internally by cursive. You probably just want
View::draw.