Struct cursive_core::buffer::Window
source · pub struct Window<'a> { /* private fields */ }Expand description
A view into a rectangular area of the buffer.
Implementations
sourceimpl<'a> Window<'a>
impl<'a> Window<'a>
sourcepub fn cell_at(&self, pos: Vec2) -> Option<&Cell>
pub fn cell_at(&self, pos: Vec2) -> Option<&Cell>
Returns the cell at the given location.
Returns None if the cell is empty because the previous one was double-wide.
sourcepub fn rows(&self) -> impl Iterator<Item = &[Option<Cell>]>
pub fn rows(&self) -> impl Iterator<Item = &[Option<Cell>]>
Iterate on the rows of this window.
sourcepub fn style_at_mut<V>(&mut self, pos: V) -> Option<&mut ConcreteStyle>
pub fn style_at_mut<V>(&mut self, pos: V) -> Option<&mut ConcreteStyle>
Get mutable access to the style at the given cell, if any.