[−][src]Enum cursive_core::direction::Orientation
Describes a vertical or horizontal orientation for a view.
Variants
Horizontal orientation
Vertical orientation
Implementations
impl Orientation[src]
pub fn pair() -> XY<Orientation>[src]
Returns a XY(Horizontal, Vertical).
pub fn get<T: Clone>(self, v: &XY<T>) -> T[src]
Returns the component of v corresponding to this orientation.
(Horizontal will return the x value,
and Vertical will return the y value.)
pub fn swap(self) -> Self[src]
Returns the other orientation.
pub fn get_ref<T>(self, v: &mut XY<T>) -> &mut T[src]
Returns a mutable reference to the component of the given vector corresponding to this orientation.
Examples
let o = Orientation::Horizontal; let mut xy = XY::new(1, 2); *o.get_ref(&mut xy) = 42; assert_eq!(xy, XY::new(42, 2));
pub fn stack<T: Iterator<Item = Vec2>>(self, iter: T) -> Vec2[src]
Takes an iterator on sizes, and stack them in the current orientation, returning the size of the required bounding box.
- For an horizontal view, returns
(Sum(x), Max(y)). - For a vertical view, returns
(Max(x), Sum(y)).
pub fn make_vec(self, main_axis: usize, second_axis: usize) -> Vec2[src]
Creates a new Vec2 with main_axis in self's axis, and
second_axis for the other axis.
Examples
let o = Orientation::Horizontal; let vec = o.make_vec(1, 2); assert_eq!(vec, Vec2::new(1, 2)); let o = Orientation::Vertical; let vec = o.make_vec(1, 2); assert_eq!(vec, Vec2::new(2, 1));