Module cursive_core::logger
source · Expand description
Logging utilities.
Structs
- Saves all log records in a global deque.
- Circular buffer for logs. Use it to implement
DebugView. - A log record.
Functions
- Return a logger that stores records in cursive’s log queue.
- Initialize the Cursive logger.
- Log a record in cursive’s log queue.
- Adds
nmore entries to cursive’s log queue. - Sets the external log filter level.
- Sets log filter levels based on environment variables
RUST_LOGandCURSIVE_LOG. IfRUST_LOGis set, then both internal and external log levels are set to match. IfCURSIVE_LOGis set, then the internal log level is set to match with precedence overRUST_LOG. - Sets the internal log filter level.