pub struct SpannedStr<'a, T> { /* private fields */ }Expand description
The immutable, borrowed equivalent of SpannedString.
Implementations
Sourceimpl<'a, T> SpannedStr<'a, T>where
T: 'a,
impl<'a, T> SpannedStr<'a, T>where
T: 'a,
Sourcepub const fn new(source: &'a str, spans: &'a [IndexedSpan<T>]) -> Self
pub const fn new(source: &'a str, spans: &'a [IndexedSpan<T>]) -> Self
Creates a new SpannedStr from the given references.
Sourcepub fn spans<'b>(
&'b self,
) -> impl DoubleEndedIterator<Item = Span<'a, T>> + ExactSizeIterator<Item = Span<'a, T>> + 'bwhere
'a: 'b,
pub fn spans<'b>(
&'b self,
) -> impl DoubleEndedIterator<Item = Span<'a, T>> + ExactSizeIterator<Item = Span<'a, T>> + 'bwhere
'a: 'b,
Gives access to the parsed styled spans.
Sourcepub const fn spans_raw(&self) -> &'a [IndexedSpan<T>]
pub const fn spans_raw(&self) -> &'a [IndexedSpan<T>]
Returns a reference to the indexed spans.
Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Returns true if self is empty.
Can be caused by an empty source, or no span.
Sourcepub fn width(&self) -> usize
pub fn width(&self) -> usize
Returns the width taken by this string.
This is the sum of the width of each span.
Sourcepub fn from_spanned_text<'b, S>(text: &'b S) -> Selfwhere
S: SpannedText<S = IndexedSpan<T>>,
'b: 'a,
pub fn from_spanned_text<'b, S>(text: &'b S) -> Selfwhere
S: SpannedText<S = IndexedSpan<T>>,
'b: 'a,
Create a new SpannedStr by borrowing from a SpannedText.