Struct cursive_core::view::SizeCache
source · pub struct SizeCache<T = ()> {
pub value: usize,
pub constrained: bool,
pub extra: T,
}Expand description
Cache around a one-dimensional layout result.
This is not a View, but something to help you if you create your own Views.
Fields
value: usizeCached value
constrained: booltrue if the last size was constrained.
If unconstrained, any request larger than this value would return the same size.
extra: TExtra field.
Implementations
sourceimpl SizeCache<()>
impl SizeCache<()>
sourcepub fn build(size: Vec2, req: Vec2) -> XY<Self>
pub fn build(size: Vec2, req: Vec2) -> XY<Self>
Creates a new bi-dimensional cache.
It will stay valid for the same request, and compatible ones.
A compatible request is one where, for each axis, either:
- the request is equal to the cached size, or
- the request is larger than the cached size and the cache is unconstrained
Notes:
sizemust fit insidereq.- for each dimension,
constrained = (size == req)