Struct cursive_core::views::ListView
source · pub struct ListView { /* private fields */ }Expand description
Displays a list of elements.
Implementations
sourceimpl ListView
impl ListView
sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if this view contains no children.
Returns false if at least a delimiter or a view is present.
sourcepub fn get_row(&self, id: usize) -> &ListChild
pub fn get_row(&self, id: usize) -> &ListChild
Returns a reference to the child at the given position.
sourcepub fn set_children(&mut self, children: Vec<ListChild>)
pub fn set_children(&mut self, children: Vec<ListChild>)
Sets the children for this view.
sourcepub fn add_child<V: IntoBoxedView + 'static>(
&mut self,
label: impl Into<String>,
view: V,
)
pub fn add_child<V: IntoBoxedView + 'static>( &mut self, label: impl Into<String>, view: V, )
Adds a view to the end of the list.
sourcepub fn child<V: IntoBoxedView + 'static>(self, label: &str, view: V) -> Self
pub fn child<V: IntoBoxedView + 'static>(self, label: &str, view: V) -> Self
Adds a view to the end of the list.
Chainable variant.
sourcepub fn add_delimiter(&mut self)
pub fn add_delimiter(&mut self)
Adds a delimiter to the end of the list.
sourcepub fn remove_child(&mut self, index: usize) -> ListChild
pub fn remove_child(&mut self, index: usize) -> ListChild
sourcepub fn set_on_select<F>(&mut self, cb: F)
pub fn set_on_select<F>(&mut self, cb: F)
Sets a callback to be used when an item is selected.
sourcepub fn on_select_cb<F: Fn(&mut Cursive, &String) + 'static + Send + Sync>(
cb: F,
) -> Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>
pub fn on_select_cb<F: Fn(&mut Cursive, &String) + 'static + Send + Sync>( cb: F, ) -> Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>
Helper method to store a callback of the correct type for Self::set_on_select.
This is mostly useful when using this view in a template.
sourcepub fn set_on_select_cb(
&mut self,
cb: Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>,
)
pub fn set_on_select_cb( &mut self, cb: Arc<dyn Fn(&mut Cursive, &String) + Send + Sync>, )
Helper method to call Self::set_on_select with a variable from a config.
This is mostly useful when writing a cursive blueprint for this view.