[−][src]Struct cursive_core::views::NamedView
Wrapper around a view to make it identifiable.
This lets other views refer to this one using a string identifier.
See Identifiable for an easy way to wrap any view with it.
Implementations
impl<V> NamedView<V>[src]
pub fn new<S: Into<String>>(name: S, view: V) -> Self[src]
Wraps view in a new NamedView.
pub fn get_mut(&mut self) -> ViewRef<V>[src]
Gets mutable access to the inner view.
This returns a ViewRef<V>, which implement DerefMut<Target = V>.
Panics
Panics if another reference for this view already exists.
pub fn name(&self) -> &str[src]
Returns the name attached to this view.
pub fn set_name<S: Into<String>>(&mut self, name: S)[src]
Changes the name attached to this view.