[−][src]Struct cursive_core::views::RadioGroup
Group to coordinate multiple radio buttons.
A RadioGroup is used to create and manage RadioButtons.
A RadioGroup can be cloned; it will keep pointing to the same group.
Implementations
impl<T: 'static> RadioGroup<T>[src]
pub fn new() -> Self[src]
Creates an empty group for radio buttons.
pub fn button<S: Into<String>>(&mut self, value: T, label: S) -> RadioButton<T>[src]
Adds a new button to the group.
The button will display label next to it, and will embed value.
pub fn selected_id(&self) -> usize[src]
Returns the id of the selected button.
Buttons are indexed in the order they are created, starting from 0.
pub fn selection(&self) -> Rc<T>[src]
Returns the value associated with the selected button.
pub fn set_on_change<F: 'static + Fn(&mut Cursive, &T)>(&mut self, on_change: F)[src]
Sets a callback to be used when the selection changes.
pub fn on_change<F: 'static + Fn(&mut Cursive, &T)>(self, on_change: F) -> Self[src]
Sets a callback to be used when the selection changes.
Chainable variant.
impl RadioGroup<String>[src]
pub fn button_str<S: Into<String>>(&mut self, text: S) -> RadioButton<String>[src]
Adds a button, using the label itself as value.